@@ -27,7 +27,7 @@
 #include "ConfWindow.h"
 #include "gmchess.h"
 
-#define version "0.20.4"
+#define version "0.20.5"
 
 Glib::ustring ui_info =
 "<ui>"
@@ -71,6 +71,7 @@ MainWindow::MainWindow():menubar(NULL)
 	ui_xml->get_widget("vbox_board",box_board);
 	ui_xml->get_widget("hbuttonbox_war",buttonbox_war);
 	ui_xml->get_widget("textview_comment",text_comment);
+	ui_xml->get_widget("textview_engine_log",text_engine_log);
 	ui_xml->get_widget("notebook",m_notebook);
 	ui_xml->get_widget("button_start",btn_start);
 	ui_xml->get_widget("button_end",btn_end);
@@ -195,6 +196,10 @@ MainWindow::MainWindow():menubar(NULL)
 	int _depth = atoi(GMConf["engine_depth"].c_str());
 	g_log("Mainwindow",G_LOG_LEVEL_INFO,"depth %d",_depth);
 	board->set_level_config(_depth,0,0,0,0,0,atoi(GMConf["usebook"].c_str()));
+	int _step_time= atoi(GMConf["step_time"].c_str());
+	int _play_time= atoi(GMConf["play_time"].c_str());
+	if(_step_time>0&&_step_time<300 && _play_time>0)
+		board->set_war_time(_step_time,_play_time);
 }
 
 MainWindow::~MainWindow()
@@ -302,6 +307,34 @@ void MainWindow::set_comment(const std::string& f_comment)
 	buffer->set_text(f_comment);
 
 }
+
+void MainWindow::show_textview_engine_log(const std::string& f_text)
+{
+
+	text_engine_log->set_wrap_mode(Gtk::WRAP_WORD);
+	Glib::RefPtr<Gtk::TextBuffer> buffer_ = text_engine_log->get_buffer();
+	Gtk::TextBuffer::iterator end_ = buffer_->end();
+
+	Gdk::Rectangle rect_;
+	text_engine_log->get_visible_rect(rect_);
+
+	int y=-1;
+	int height = -1;
+	text_engine_log->get_line_yrange(end_,y,height);
+
+	buffer_->place_cursor(buffer_->insert(end_,f_text));
+
+	if(y<rect_.get_y() + rect_.get_height()+16)
+		text_engine_log->scroll_to_mark(buffer_->get_insert(),0);
+}
+void MainWindow::textview_engine_log_clear()
+{
+	Glib::RefPtr<Gtk::TextBuffer> buffer_ = text_engine_log->get_buffer();
+	Gtk::TextBuffer::iterator end_ , start_ ;
+	buffer_->get_bounds(start_,end_);
+	buffer_->erase(start_,end_);
+}
+
 void MainWindow::show_treeview_step()
 {
 	Glib::RefPtr<Gtk::TreeModel> model= m_treeview.get_model();
@@ -620,20 +653,20 @@ void MainWindow::on_menu_help()
 
 }
 
+
 void MainWindow::on_menu_about()
 {
 	static Gtk::AboutDialog*  about(0);
 	if(about == 0){
 		std::vector<Glib::ustring> authors;
-		authors.push_back("lerosua ");
-		authors.push_back("wind");
+		authors.push_back("lerosua@gmail.com ");
+		authors.push_back("wind(xihels@gmail.com)");
 		about = new Gtk::AboutDialog ;
 		about->set_logo(ui_logo);
 		if(GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>=12)
 			about->set_program_name("GMChess");
 		about->set_version(version);
 		about->set_website("http://lerosua.org");
-		//about->set_website_label("lerosua");
 		about->set_copyright("Copyright (c) 2009 lerosua");
 		about->set_comments(_("GMChess is chinese chess game write by gtkmm"));
 		about->set_authors(authors);
@@ -910,6 +943,12 @@ bool MainWindow::on_end_game(OVERSTATUS _over)
 			//robot want to draw
 			msg=_("Computer want to draw with you, are you agree?");
 			break;
+		case ROBOT_OVER_TIME:
+			// robot overload time,lose
+			msg = _("The Enemy overload the time, You Win!");
+			break;
+		case HUMAN_OVER_TIME:
+			msg = _("You overload the time, You Lose!");
 		default:
 			break;
 
