@@ -147,6 +147,6 @@ static const int BishopMoveTab[4]  = {-0x22, -0x1e, +0x1e, +0x22};
 static const int KnightMoveTab[8]  = {-0x21, -0x1f, -0x12, -0x0e, +0x0e, +0x12, +0x1f, +0x21};
 
 enum BOARDSIZE {BIG_BOARD=0, SMALL_BOARD};
-enum OVERSTATUS {ROBOT_WIN=0,ROBOT_LOSE,ROBOT_DRAW};
+enum OVERSTATUS {ROBOT_WIN=0,ROBOT_LOSE,ROBOT_DRAW, ROBOT_OVER_TIME,HUMAN_OVER_TIME};
 #endif   /* ----- #ifndef GMCHESS_FILE_HEADER_INC  ----- */
 
